from setuptools import setup


setup(
    name='databasedict',
    packages=["databasedict"],
    version='0.0.0',
    author='Perzan',
    author_email='PerzanDevelopment@gmail.com',
    install_requires=["onetrick~=2.1"]
)